@@ -119,7 +119,7 @@ class Platform(Enum):
     Liquids = "https://api.kpler.com/v1"  #:
 
 
-class TradeStatus(Enum):
+class TradesStatus(Enum):
     """"""
 
     Delivered = "delivered"  #:
@@ -169,7 +169,7 @@ class FleetDevelopmentSeriesUnit(Enum):
     KT = "kt"  #:
 
 
-class FlowDirection(Enum):
+class FlowsDirection(Enum):
     """"""
 
     Import = "import"  #:
@@ -178,7 +178,7 @@ class FlowDirection(Enum):
     NetExport = "netexport"  #:
 
 
-class FlowSplit(Enum):
+class FlowsSplit(Enum):
     """"""
 
     Total = "total"  #:
@@ -197,7 +197,7 @@ class FlowSplit(Enum):
     Sellers = "seller"  #:
 
 
-class FlowPeriod(Enum):
+class FlowsPeriod(Enum):
     """"""
 
     Annually = "annually"  #:
@@ -207,7 +207,7 @@ class FlowPeriod(Enum):
     Daily = "daily"  #:
 
 
-class FlowMeasurementUnit(Enum):
+class FlowsMeasurementUnit(Enum):
     """"""
 
     KBD = "kbd"  #:
@@ -220,7 +220,7 @@ class FlowMeasurementUnit(Enum):
     CM = "cm"  #:
 
 
-class FreightMetricSeriesMetric(Enum):
+class FreightMetricsSeriesMetric(Enum):
     """"""
 
     TonMiles = "TonMiles"  #:
@@ -229,7 +229,7 @@ class FreightMetricSeriesMetric(Enum):
     AvgDistance = "AvgDistance"  #:
 
 
-class FreightMetricSeriesPeriod(Enum):
+class FreightMetricsSeriesPeriod(Enum):
     """"""
 
     Monthly = "monthly"  #:
@@ -237,7 +237,7 @@ class FreightMetricSeriesPeriod(Enum):
     Annually = "annually"  #:
 
 
-class FreightMetricSeriesSplit(Enum):
+class FreightMetricsSeriesSplit(Enum):
     """"""
 
     Total = "total"  #:
@@ -252,7 +252,7 @@ class FreightMetricSeriesSplit(Enum):
     OriginSourceEta = "originSourceEta"  #:
 
 
-class FreightMetricSeriesUnit(Enum):
+class FreightMetricsSeriesUnit(Enum):
     """"""
 
     MTNMI = "mt/nmi"  #:
@@ -340,14 +340,14 @@ class FleetDevelopmentVesselsMetric(Enum):
     Scrapping = "scrapping"  #:
 
 
-class FleetMetricAlgo(Enum):
+class FleetMetricsAlgo(Enum):
     """"""
 
     FloatingStorage = "floating_storage"  #:
     LoadedVessels = "loaded_vessels"  #:
 
 
-class FleetMetricPeriod(Enum):
+class FleetMetricsPeriod(Enum):
     """"""
 
     Weekly = "weekly"  #:
@@ -355,7 +355,7 @@ class FleetMetricPeriod(Enum):
     EIA = "eia"  #:
 
 
-class FleetMetricMeasurementUnit(Enum):
+class FleetMetricsMeasurementUnit(Enum):
     """"""
 
     BBL = "bbl"  #:
@@ -363,7 +363,7 @@ class FleetMetricMeasurementUnit(Enum):
     CM = "cm"  #:
 
 
-class FleetMetricSplit(Enum):
+class FleetMetricsSplit(Enum):
     """"""
 
     Total = "total"  #:
@@ -386,14 +386,14 @@ class FleetMetricSplit(Enum):
     FloatingDays = "floating days"  #:
 
 
-class FleetMetricVesselsAlgo(Enum):
+class FleetMetricsVesselsAlgo(Enum):
     """"""
 
     FloatingStorage = "floating_storage"  #:
     LoadedVessels = "loaded_vessels"  #:
 
 
-class FleetMetricVesselsMeasurementUnit(Enum):
+class FleetMetricsVesselsMeasurementUnit(Enum):
     """"""
 
     BBL = "bbl"  #:
@@ -405,14 +405,14 @@ class FleetMetricVesselsMeasurementUnit(Enum):
     CM = "cm"  #:
 
 
-class OutageTypes(Enum):
+class OutagesTypes(Enum):
     """"""
 
     Planned = "planned"  #:
     Unplanned = "unplanned"  #:
 
 
-class PriceIndexes(Enum):
+class PricesIndexes(Enum):
     """"""
 
     NBP = "NBP"  #:
@@ -427,7 +427,7 @@ class PriceIndexes(Enum):
     JCC = "JCC"  #:
 
 
-class ContractTypes(Enum):
+class ContractsTypes(Enum):
     """"""
 
     SPA = "SPA"  #:
